"""Classes representing rovibrational molecular states."""

from typing import Union
from attrs import define, field


@define(frozen=True, cache_hash=True, order=True)
class DiatomState:
    nu: int
    j: int
    name: str = field(init=False, eq=False, repr=False)

    def __attrs_post_init__(self):
        object.__setattr__(self, "name", "{:d},{:d}".format(self.nu, self.j))

    @classmethod
    def from_symtop(cls, symtop: "SymTopState"):
        return cls(symtop.nu, symtop.j)


@define(frozen=True, cache_hash=True, order=True)
class SymTopState:
    nu: int
    j: int
    k: int
    name: str = field(init=False, eq=False, repr=False)

    def __attrs_post_init__(self):
        object.__setattr__(
            self, "name", "{:d},{:d},{:d}".format(self.nu, self.j, self.k)
        )

    @classmethod
    def from_diatom(cls, diatom: DiatomState, k: int):
        return cls(diatom.nu, diatom.j, k)


RotState = Union[DiatomState, SymTopState]
